%define build_ocamlopt	1
%ifarch ppc64 %mips
%define build_ocamlopt	0
%endif
%define major	4.02

%bcond_with bootstrap

# we don't want the auto require to add require on the currently installed ocaml
%global __requires_exclude ocaml|^/

Name:		ocaml
Version:	4.02.3
Release:	%mkrel 1
Summary:	The OCaml compiler and programming environment
URL:		http://caml.inria.fr
License:	QPL with exceptions and LGPLv2 with exceptions
Group:		Development/OCaml
Source0:	http://caml.inria.fr/pub/distrib/ocaml-%{major}/%{name}-%{version}.tar.xz
Source1:	http://caml.inria.fr/pub/distrib/ocaml-%{major}/%{name}-%{major}beta-refman-html.tar.gz

# IMPORTANT: 
# The contents (META's files) of this tarball comes from findlib
# This tarball have to be updated when findlib or ocaml are updated to a
# new version these META's files are only generated by the ./configure in
# the findlib source directory (ocaml-x11
# and ocaml-compiler-libs have to be installed for this operation) then
# just: 
# tar cfj findlib-1.4-ocaml-4.00.1-meta-files.tar.bz2 site-lib-src/*/META
Source5:	findlib-1.6.1-ocaml-4.02.3-meta-files.tar.bz2

Patch3:		ocaml-3.11.0-ocamltags-no-site-start.patch
Patch6:		ocaml-3.04-do-not-add-rpath-X11R6_lib-when-using-option-L.patch
Patch8:		ocaml-3.04-larger-buffer-for-uncaught-exception-messages.patch
Patch16:	ocaml-3.09.2-lib64.patch
Patch18:	ocaml-3.09.3-compile-emacs-files-in-build-dir.patch
# Workaround for upstream http://caml.inria.fr/mantis/view.php?id=5753
# Remove ocamltoplevel.cmxa from META file
Patch19:	ocaml-4.00.1-fix-META-ocamltoplevel.cmxa.patch
# Fedora patch fixing http://openwall.com/lists/oss-security/2016/04/29/1 + a few other places
Patch20:	0020-fix-PR-7003-and-a-few-other-bugs-caused-by-misuse-of.patch

BuildRequires:	libx11-devel
BuildRequires:	ncurses-devel
BuildRequires:	tcl
BuildRequires:	tcl-devel
BuildRequires:	tk
BuildRequires:	tk-devel
BuildRequires:	emacs

# This BR is to enable automatic provides generation for this package.
# It can be removed safely if we need to bootstrap.
%if ! %with bootstrap
BuildRequires:  ocaml-compiler
%endif

Requires:	ncurses-devel
%if ! %with bootstrap
Requires:	ocaml-compiler = %{version}
%endif
Requires:	ocaml-x11 = %{version}

Obsoletes:	ocaml-emacs < %{version}
Provides:	ocaml-emacs = %{version}

%package	compiler
Summary:	Compiler and Runtime for OCaml
Group:		Development/OCaml
Conflicts:	ocaml < 3.12.1-7
Provides:       ocaml(compiler) = %{version}
Provides:       ocaml(runtime) = %{version}

%package	doc
Summary:	Documentation for OCaml
Group:		Documentation
BuildArch:	noarch
Requires:	%{name}-compiler = %{version}

%package x11
Summary:	X11 library for OCaml
Group:		Development/OCaml
Requires:	%{name}-compiler = %{version}
Requires:	libx11-devel
# 2012-07-14: conflict for upgrade (when the x11 subpackage is created)
Conflicts:	ocaml < 3.12.1-7

%package sources
Summary:	OCaml sources
Group:		Development/OCaml
BuildArch:	noarch
# don't add crazy deps
AutoReqProv: no

%package compiler-libs
Summary:	OCaml compiler library
Group:		Development/OCaml
Requires:	%{name}-compiler = %{version}

%description
OCaml is a high-level, strongly-typed, functional and object-oriented
programming language from the ML family of languages.

%description compiler
This package comprises two batch OCaml compilers (a fast byte-code compiler and an
optimizing native-code compiler), an interactive top-level system, Lex&Yacc
tools, a replay debugger, and a comprehensive library.

%description	doc
Documentation for OCaml

%description x11
X11 library for OCaml.

%description sources
OCaml sources

%description compiler-libs
This package contains several modules used internally by the OCaml
compilers.  They are not needed for normal OCaml development, but may
be helpful in the development of certain applications.

%prep
%setup -q -T -b 0
%setup -q -T -D -a 1
%setup -q -T -D -a 5
%patch3 -p1
%patch6 -p1
%patch8 -p1
#patch16 -p1 -b .lib64
#patch18 -p1 -b .emacs
%patch19 -p1

rm -rf `find -name .cvsignore`

%build
%ifarch alpha
echo %{optflags} | grep -q mieee || { echo "on alpha you need -mieee to compile ocaml"; exit 1; }
%endif

./configure -bindir %{_bindir} -libdir %{_libdir}/ocaml -mandir %{_mandir}/man1
make world
%if %{build_ocamlopt}
make opt opt.opt
%endif

%install
make install BINDIR=%{buildroot}%{_bindir} LIBDIR=%{buildroot}%{_libdir}/ocaml MANDIR=%{buildroot}%{_mandir}

make -C emacs ocamltags
cd emacs; make install install-ocamltags BINDIR=%{buildroot}%{_bindir} EMACSDIR=%{buildroot}%{_datadir}/emacs/site-lisp; cd -

# fix
perl -pi -e "s|%{buildroot}||" %{buildroot}%{_libdir}/ocaml/ld.conf

%if %{build_ocamlopt}
# only keep the binary versions, which are much faster
for i in %{buildroot}%{_bindir}/*.opt ; do
  ln -sf `basename $i` ${i%.opt}
done
%endif


install -d %{buildroot}%{_sysconfdir}/emacs/site-start.d
cat <<EOF >%{buildroot}%{_sysconfdir}/emacs/site-start.d/%{name}.el
(require 'caml-font)
(autoload 'caml-mode "caml" "Caml editing mode" t)
(add-to-list 'auto-mode-alist '("\\\\.mli?$" . caml-mode))
EOF

# don't package mano man pages since we have the html files
rm -rf %{buildroot}%{_mandir}/mano

# install findlib META files
cp -pr site-lib-src/* %{buildroot}%{_libdir}/ocaml/

# fix me: this one should not be in the input
if [ -f %{buildroot}%{_libdir}/ocaml/dbm/META ]
then rm -f %{buildroot}%{_libdir}/ocaml/dbm/META; fi


rm -f %{name}.list
n="graphics|X11"
(cd %{buildroot} ; find usr/bin ! -type d -printf "/%%p\n" | grep -v -E $n) >> %{name}.list
(cd %{buildroot} ; find usr/%{_lib}/ocaml ! -type d -printf "/%%p\n" | grep -v -E $n) >> %{name}.list
(cd %{buildroot} ; find usr/%{_lib}/ocaml   -type d -printf "%%%%dir /%%p\n" | grep -v -E $n) >> %{name}.list

mkdir -p %{buildroot}%{_datadir}/applications
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop << EOF
[Desktop Entry]
Name=OCaml
Comment=ML language implementation with a class-based object system
Comment[fr]=mise en oeuvre de Meta Language (ML) avec un système orienté
Comment[ru]=Реализация языка ML с объектно-ориентированным подходом
GenericName=OCaml compiler and programming environment
GenericName[fr]=Environnement de programmation et compilateur OCaml
GenericName[ru]=Компилятор OCaml и среда программирования
Exec=%{name}
Icon=development_tools_section
Terminal=true
Type=Application
Categories=Development;
EOF


# install sources
install -d -m 755 %{buildroot}%{_prefix}/src
xzcat %{SOURCE0} | tar xvf - -C %{buildroot}%{_prefix}/src
mv %{buildroot}%{_prefix}/src/%{name}-%{version} %{buildroot}%{_prefix}/src/%{name}


%files

%files compiler -f %{name}.list
%doc Changes LICENSE README
%{_mandir}/man1/*
%{_datadir}/applications/*
%{_datadir}/emacs/site-lisp/*
%config(noreplace) %{_sysconfdir}/emacs/site-start.d/*
%exclude %{_libdir}/ocaml/compiler-libs

%files doc
%doc htmlman/* 
%{_mandir}/man3/*

%files x11
%if %{build_ocamlopt}
%{_libdir}/ocaml/graphics.a
%endif
%{_libdir}/ocaml/graphics.cma
%{_libdir}/ocaml/graphics.cmi
%if %{build_ocamlopt}
%{_libdir}/ocaml/graphics.cmx
%{_libdir}/ocaml/graphics.cmxa
%{_libdir}/ocaml/graphics.cmxs
%endif
%{_libdir}/ocaml/graphics.mli
%{_libdir}/ocaml/libgraphics.a
%{_libdir}/ocaml/stublibs/dllgraphics.so
%{_libdir}/ocaml/graphics/META
%dir %{_libdir}/ocaml/graphics
%{_libdir}/ocaml/graphicsX11.cmi
%if %{build_ocamlopt}
%{_libdir}/ocaml/graphicsX11.cmx
%endif
%{_libdir}/ocaml/graphicsX11.mli

%files sources
%{_prefix}/src/%{name}

%files compiler-libs
%dir %{_libdir}/ocaml/compiler-libs
%{_libdir}/ocaml/compiler-libs/META
%{_libdir}/ocaml/compiler-libs/*.cmi
%{_libdir}/ocaml/compiler-libs/*.cmo
%{_libdir}/ocaml/compiler-libs/*.cma
%if %{build_ocamlopt}
%{_libdir}/ocaml/compiler-libs/*.a
%{_libdir}/ocaml/compiler-libs/*.cmxa
%{_libdir}/ocaml/compiler-libs/*.cmx
%{_libdir}/ocaml/compiler-libs/*.o
%endif


%changelog
* Thu Nov 24 2016 neoclust <neoclust> 4.02.3-1.mga5
+ Revision: 1069684
- New version 4.02.3 ( Fixes CVE-2015-8869)

* Fri Nov 28 2014 alexl <alexl> 4.01.0-11.mga5
+ Revision: 799756
- new Comment for desktop file

* Sun Nov 23 2014 alexl <alexl> 4.01.0-10.mga5
+ Revision: 798422
- add GenericName
- translate desktop file into Russian

* Wed Oct 15 2014 umeabot <umeabot> 4.01.0-9.mga5
+ Revision: 744270
- Second Mageia 5 Mass Rebuild

* Mon Sep 22 2014 pterjan <pterjan> 4.01.0-8.mga5
+ Revision: 713461
- Try again fixing requires

* Sun Sep 21 2014 pterjan <pterjan> 4.01.0-7.mga5
+ Revision: 712104
- Try fixing requires

* Wed Sep 17 2014 malo <malo> 4.01.0-6.mga5
+ Revision: 691656
- add missing provides

* Wed Sep 17 2014 malo <malo> 4.01.0-5.mga5
+ Revision: 691426
- BuildRequires ocaml-compiler to automatically generate provides

* Tue Sep 16 2014 umeabot <umeabot> 4.01.0-4.mga5
+ Revision: 682973
- Mageia 5 Mass Rebuild

  + tv <tv>
    - use %%global for req/prov exclude
    - autoconvert to new prov/req excludes

* Sat Oct 19 2013 umeabot <umeabot> 4.01.0-3.mga4
+ Revision: 534514
- Mageia 4 Mass Rebuild

* Thu Sep 12 2013 blue_prawn <blue_prawn> 4.01.0-2.mga4
+ Revision: 478180
- updated to last version 4.01.0 (aka. Ir?\195?\168ne's release)

* Sat Sep 07 2013 blue_prawn <blue_prawn> 4.01.0-1.rc2.mga4
+ Revision: 475717
- updated to last RC version 4.01.0+rc2

* Wed Jul 31 2013 blue_prawn <blue_prawn> 4.00.1-8.mga4
+ Revision: 461612
- updated META files from findlib 1.4
- updated META files from findlib 1.4

* Sun Jun 09 2013 fwang <fwang> 4.00.1-7.mga4
+ Revision: 441006
- only libx11 is required

* Sat Mar 09 2013 rtp <rtp> 4.00.1-6.mga3
+ Revision: 401972
- fix build with ocaml opt disabled
- enable ocaml opt on arm as native arm eabi soft float is there now

* Sat Jan 19 2013 malo <malo> 4.00.1-5.mga3
+ Revision: 389843
- add patch to compiler-libs META file to workaround upstream bug 5753

* Sat Jan 12 2013 umeabot <umeabot> 4.00.1-4.mga3
+ Revision: 361116
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Nov 23 2012 blue_prawn <blue_prawn> 4.00.1-3.mga3
+ Revision: 321414
- the file +dbm/META should not be included

* Tue Nov 20 2012 blue_prawn <blue_prawn> 4.00.1-2.mga3
+ Revision: 319735
- libdb is not used anymore
- libdb is not used anymore

* Fri Oct 05 2012 blue_prawn <blue_prawn> 4.00.1-1.mga3
+ Revision: 302936
- update to last version 4.00.1

* Mon Oct 01 2012 blue_prawn <blue_prawn> 4.00.0-4.mga3
+ Revision: 301268
- needs to be rebuilt
- removed old comments

* Mon Oct 01 2012 blue_prawn <blue_prawn> 4.00.0-3.mga3
+ Revision: 301136
- dbm has disappeared, don't require it
- dbm has disappeared, don't require it

* Sun Sep 30 2012 blue_prawn <blue_prawn> 4.00.0-2.mga3
+ Revision: 301066
- build with patches
- adapt patch9 for ocaml 4.00.0
- adapt patch6 for ocaml 4.00.0
- dbm is not in the main distribution anymore (it is released separated now)

* Sun Sep 30 2012 malo <malo> 4.00.0-1.mga3
+ Revision: 301001
- update to new version 4.00.0

  + blue_prawn <blue_prawn>
    - new rpm group for ocaml

* Mon Sep 03 2012 blue_prawn <blue_prawn> 3.12.1-12.mga3
+ Revision: 287681
- removed dependency on libX11.so from the ocaml-compiler split (the related files have been put in the ocaml-x11 split)
- put the file compiler-libs/META in the right split

* Mon Aug 06 2012 blue_prawn <blue_prawn> 3.12.1-11.mga3
+ Revision: 279313
- added the split "ocaml-compiler-libs" needed by some packages
- The name "Objective Caml" shouldn't be used anymore, we should use only "OCaml" now (as decided by the community)

* Tue Jul 31 2012 fwang <fwang> 3.12.1-10.mga3
+ Revision: 276433
- force system db devel package

* Tue Jul 31 2012 fwang <fwang> 3.12.1-9.mga3
+ Revision: 276392
- build with db 5.3

* Sat Jul 21 2012 malo <malo> 3.12.1-8.mga3
+ Revision: 273107
- update for new findlib 1.3.3

* Fri Jul 20 2012 malo <malo> 3.12.1-7.mga3
+ Revision: 272951
- fix X11-devel dependency
- split ocaml into ocaml-compiler, ocaml-x11 and ocaml-dbm in order to remove
  the chain of requires: ocaml-compiler does not need x11.

* Thu Jun 14 2012 tv <tv> 3.12.1-6.mga3
+ Revision: 260492
- fix requires

* Thu Jun 14 2012 tv <tv> 3.12.1-5.mga3
+ Revision: 260477
- build with db5.2

* Thu Mar 08 2012 malo <malo> 3.12.1-4.mga2
+ Revision: 221439
- fix desktop file (mga#3635)

  + blue_prawn <blue_prawn>
    - updated META files from new findlib 1.2.8
    - Mageia SPEC syntax policy

* Sun Dec 04 2011 malo <malo> 3.12.1-3.mga2
+ Revision: 176299
- missing requires to libx11-devel, db4-devel, ncurses-devel
- splitting camlp4 with devel package, per Ocaml policy

* Sat Dec 03 2011 malo <malo> 3.12.1-2.mga2
+ Revision: 175622
- Fix file duplication in ocaml, camlp4 and ocaml-labltk
- spec cleanup

* Sat Oct 01 2011 shlomif <shlomif> 3.12.1-1.mga2
+ Revision: 150784
- Version 3.12.1 - thanks to Malo.

* Sat Jul 02 2011 fwang <fwang> 3.12.0-3.mga2
+ Revision: 117454
- Adding upstream patch fixing bad interactions between ocaml and binutils 2.21 (see http://caml.inria.fr/mantis/view.php?id=5237)

* Tue Apr 12 2011 ennael <ennael> 3.12.0-2.mga1
+ Revision: 83719
- add missing provides

  + ahmad <ahmad>
    - imported package ocaml


* Sat Aug 28 2010 Florent Monnier <blue_prawn@mandriva.org> 3.12.0-1mdv2011.0
+ Revision: 573767
- updated to last version 3.12.0

* Mon Aug 23 2010 Florent Monnier <blue_prawn@mandriva.org> 3.11.2-4mdv2011.0
+ Revision: 572373
- updated META files provided by findlib version 1.2.6

* Mon Mar 01 2010 Guillaume Rousse <guillomovitch@mandriva.org> 3.11.2-3mdv2010.1
+ Revision: 512981
- fix camlp4 META file correctly

* Mon Mar 01 2010 Guillaume Rousse <guillomovitch@mandriva.org> 3.11.2-2mdv2010.1
+ Revision: 512910
- emacs is insufficient to compile bytecode, switch to full emacs
- fix incorrect META file for camlp4 on x86_64
- new version

* Fri Jan 01 2010 Oden Eriksson <oeriksson@mandriva.com> 3.11.1-5mdv2010.1
+ Revision: 484726
- rebuilt against bdb 4.8

* Sun Sep 27 2009 Olivier Blin <oblin@mandriva.com> 3.11.1-4mdv2010.0
+ Revision: 450174
- disable ocaml.opt* on mips & arm, not supported
  (from Arnaud Patard)

* Fri Sep 11 2009 Florent Monnier <blue_prawn@mandriva.org> 3.11.1-3mdv2010.0
+ Revision: 438520
- restore the previous solution to manage META files (sync for the tarball)
- restore the previous solution to manage META files

* Wed Sep 09 2009 Florent Monnier <blue_prawn@mandriva.org> 3.11.1-2mdv2010.0
+ Revision: 435818
- this tarball was not updated when ocaml and ocaml-findlib was updated,
  and there are currently things broken with this old tarball,
  instead of updating it, I think it's better to keep it in findlib where it's easier to keep it maintained

* Thu Jun 25 2009 Frederik Himpe <fhimpe@mandriva.org> 3.11.1-1mdv2010.0
+ Revision: 389199
- update to new version 3.11.1

* Wed Dec 24 2008 Guillaume Rousse <guillomovitch@mandriva.org> 3.11.0-2mdv2009.1
+ Revision: 318162
- rediff fuzzy patches
- site-lib hierarchy doesn't exist anymore

* Mon Dec 08 2008 Pixel <pixel@mandriva.com> 3.11.0-1mdv2009.1
+ Revision: 311906
- 3.11.0
- rediff/adapt patch9 (tk)

* Sat Dec 06 2008 Adam Williamson <awilliamson@mandriva.org> 3.10.2-5mdv2009.1
+ Revision: 310971
- rebuild for new tcl
- update tcl handling patch for 8.6
- new license policy

* Mon Sep 15 2008 Guillaume Rousse <guillomovitch@mandriva.org> 3.10.2-4mdv2009.0
+ Revision: 284872
- keep both bytecode and native versions for camlp4, as native ones have troubles with dynamic loading

* Mon Sep 01 2008 Guillaume Rousse <guillomovitch@mandriva.org> 3.10.2-3mdv2009.0
+ Revision: 278643
- re-enable optimized versions of camlp4

* Tue Jun 17 2008 Thierry Vignaud <tv@mandriva.org> 3.10.2-2mdv2009.0
+ Revision: 223356
- rebuild

* Sun Mar 02 2008 Stefan van der Eijk <stefan@mandriva.org> 3.10.2-1mdv2008.1
+ Revision: 177752
- 3.10.2, as per bug 37508

* Thu Dec 27 2007 Oden Eriksson <oeriksson@mandriva.com> 3.10.0-5mdv2008.1
+ Revision: 138206
- rebuilt against bdb 4.6.x libs

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Sep 07 2007 Anssi Hannula <anssi@mandriva.org> 3.10.0-4mdv2008.0
+ Revision: 82024
- rebuild for new soname of tcl

* Sun Sep 02 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.10.0-3mdv2008.0
+ Revision: 78255
- disable automatic dependencies for source package

* Sat Sep 01 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.10.0-2mdv2008.0
+ Revision: 77694
- add an ocaml-sources subpackage for cduce

* Tue May 29 2007 Pixel <pixel@mandriva.com> 3.10.0-1mdv2008.0
+ Revision: 32452
- new release, 3.10.0
- handle tk 8.5


* Tue Feb 20 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.09.3-5mdv2007.0
+ Revision: 123095
- use relative directory notation for camlp4 META file, so as to fix x86_64 usage

* Tue Feb 20 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.09.3-4mdv2007.1
+ Revision: 123047
- minor spec cleanup
- make sure shared libs under site-lib are available for loading

* Thu Jan 25 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.09.3-3mdv2007.1
+ Revision: 113230
- only ships META files for standard library, not findlib library itself

* Wed Jan 24 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.09.3-2mdv2007.1
+ Revision: 112752
- ensure emacs bytecode file are compiled in build dir, to avoid wrong files in install dir
- oops, increment release, not minor version
- spec file cleanup
- ship META files for findlib
- rename ocamltk package to ocaml-labltk

  + Crispin Boylan <crisb@mandriva.org>
    - Add patch to use db4 (closes #27858)

  + Gwenole Beauchesne <gbeauchesne@mandriva.com>
    - ppc64 fixes
    - 3.09.3
    - Import ocaml

* Thu Sep 21 2006 Gwenole Beauchesne <gbeauchesne@mandriva.com> 3.09.2-4mdv2007.0
- improve lib64 patch for X.org 7.1 paths

* Thu Sep 21 2006 Nicolas Lcureuil <neoclust@mandriva.org> 3.09.2-3mdv2007.0
-  Rebuild against ncurse

* Sat May 20 2006 Guillaume Rousse <guillomovitch@mandriva.org> 3.09.2-2mdk
- ocaml-camltk requires tk-devel

* Tue Apr 25 2006 Pixel <pixel@mandriva.com> 3.09.2-1mdk
- new release

* Fri Jan 13 2006 Pixel <pixel@mandriva.com> 3.09.1-2mdk
- fix typo :-(

* Fri Jan 13 2006 Pixel <pixel@mandriva.com> 3.09.1-1mdk
- new release

* Mon Jan 02 2006 Oden Eriksson <oeriksson@mandriva.com> 3.09.0-2mdk
- rebuilt against soname aware deps (tcl/tk)
- fix deps

* Thu Nov 03 2005 Pixel <pixel@mandriva.com> 3.09.0-1mdk 
- new release
- drop add-warning-for-unused-local-variables patch
  (included upstream, neatly called warning "Z" :)

* Wed Apr 27 2005 Per Øyvind Karlsen <peroyvind@mandriva.org> 3.08.3-2mdk
- fix buildrequires
- %%mkrel

* Wed Apr 27 2005 Per Øyvind Karlsen <peroyvind@mandriva.org> 3.08.3-1mdk
- 3.08.3
- cosmetics

* Wed Dec 01 2004 Guillaume Rousse <guillomovitch@mandrake.org> 3.08.2-1mdk 
- new release
- removed packager tag
- rpmbuildupdate aware

* Tue Nov 09 2004 Pixel <pixel@mandrakesoft.com> 3.08.1-1mdk
- new release

* Fri Jul 16 2004 Pixel <pixel@mandrakesoft.com> 3.08-3mdk
- new release

* Tue Jun 29 2004 Christiaan Welvaart <cjw@daneel.dyndns.org> 3.07.2-3mdk
- BuildRequires: tcl

* Sat Apr 17 2004 Pixel <pixel@mandrakesoft.com> 3.07.2-2mdk
- don't modify BYTECCCOMPOPTS and NATIVECCCOMPOPTS, otherwise
  -D_FILE_OFFSET_BITS=64 is dropped (bugzilla #9502)
  => don't pass optflags (hope it won't break AXP which needs -mieee)
- have less warnings when compiling

